Trait AccountFields
pub trait AccountFields: LedgerObjectCommonFields {
Show 21 methods
// Provided methods
fn get_account(&self) -> Result<AccountID> { ... }
fn account_txn_id(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>> { ... }
fn amm_id(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>> { ... }
fn balance(&self) -> Result<Option<Amount>> { ... }
fn burned_nf_tokens(&self) -> Result<Option<u32>> { ... }
fn domain(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::UriBlob::{constant#0}>>> { ... }
fn email_hash(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt128::{constant#0}>>> { ... }
fn first_nf_token_sequence(&self) -> Result<Option<u32>> { ... }
fn ledger_entry_type(&self) -> Result<u16> { ... }
fn message_key(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::PublicKeyBlob::{constant#0}>>> { ... }
fn minted_nf_tokens(&self) -> Result<Option<u32>> { ... }
fn nf_token_minter(&self) -> Result<Option<AccountID>> { ... }
fn owner_count(&self) -> Result<u32> { ... }
fn previous_txn_id(
&self,
) -> Result<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>> { ... }
fn previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn regular_key(&self) -> Result<Option<AccountID>> { ... }
fn sequence(&self) -> Result<u32> { ... }
fn ticket_count(&self) -> Result<Option<u32>> { ... }
fn tick_size(&self) -> Result<Option<u8>> { ... }
fn transfer_rate(&self) -> Result<Option<u32>> { ... }
fn wallet_locator(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>> { ... }
}Expand description
Trait providing access to fields specific to AccountRoot objects in any ledger.
This trait extends LedgerObjectCommonFields and provides methods to access
fields that are specific to Escrow objects in any ledger, not just the current one.
Each method requires a register number to identify which ledger object to access.
Provided Methods
fn get_account(&self) -> Result<AccountID>
fn get_account(&self) -> Result<AccountID>
The identifying address of the account.
fn account_txn_id(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>>
fn account_txn_id( &self, ) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>>
AccountTxnID field for the account.
fn amm_id(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>>
fn amm_id( &self, ) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>>
The ledger entry ID of the corresponding AMM ledger entry. Set during account creation; cannot be modified. If present, indicates that this is a special AMM AccountRoot; always omitted on non-AMM accounts. (Added by the AMM amendment)
fn burned_nf_tokens(&self) -> Result<Option<u32>>
fn burned_nf_tokens(&self) -> Result<Option<u32>>
How many total of this account’s issued non-fungible tokens have been burned. This number is always equal or less than MintedNFTokens.
fn domain(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::UriBlob::{constant#0}>>>
fn domain( &self, ) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::UriBlob::{constant#0}>>>
A domain associated with this account. In JSON, this is the hexadecimal for the ASCII representation of the domain. Cannot be more than 256 bytes in length.
fn email_hash(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt128::{constant#0}>>>
fn email_hash( &self, ) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt128::{constant#0}>>>
The MD5 hash of an email address. Clients can use this to look up an avatar through services such as Gravatar.
fn first_nf_token_sequence(&self) -> Result<Option<u32>>
fn first_nf_token_sequence(&self) -> Result<Option<u32>>
The account’s Sequence Number at the time it minted its first non-fungible-token. (Added by the fixNFTokenRemint amendment)
fn ledger_entry_type(&self) -> Result<u16>
fn ledger_entry_type(&self) -> Result<u16>
The value 0x0061, mapped to the string AccountRoot, indicates that this is an AccountRoot object.
fn message_key(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::PublicKeyBlob::{constant#0}>>>
fn message_key( &self, ) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::PublicKeyBlob::{constant#0}>>>
A public key that may be used to send encrypted messages to this account. In JSON, uses hexadecimal. Must be exactly 33 bytes, with the first byte indicating the key type: 0x02 or 0x03 for secp256k1 keys, 0xED for Ed25519 keys.
fn minted_nf_tokens(&self) -> Result<Option<u32>>
fn minted_nf_tokens(&self) -> Result<Option<u32>>
How many total non-fungible tokens have been minted by and on behalf of this account. (Added by the NonFungibleTokensV1_1 amendment)
fn nf_token_minter(&self) -> Result<Option<AccountID>>
fn nf_token_minter(&self) -> Result<Option<AccountID>>
Another account that can mint non-fungible tokens on behalf of this account. (Added by the NonFungibleTokensV1_1 amendment)
fn owner_count(&self) -> Result<u32>
fn owner_count(&self) -> Result<u32>
The number of objects this account owns in the ledger, which contributes to its owner reserve.
fn previous_txn_id(
&self,
) -> Result<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>
fn previous_txn_id( &self, ) -> Result<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>
The identifying hash of the transaction that most recently modified this object.
fn previous_txn_lgr_seq(&self) -> Result<u32>
fn previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this object.
fn regular_key(&self) -> Result<Option<AccountID>>
fn regular_key(&self) -> Result<Option<AccountID>>
The address of a key pair that can be used to sign transactions for this account instead of the master key. Use a SetRegularKey transaction to change this value.
fn sequence(&self) -> Result<u32>
fn sequence(&self) -> Result<u32>
The sequence number of the next valid transaction for this account.
fn ticket_count(&self) -> Result<Option<u32>>
fn ticket_count(&self) -> Result<Option<u32>>
How many Tickets this account owns in the ledger. This is updated automatically to ensure that the account stays within the hard limit of 250 Tickets at a time. This field is omitted if the account has zero Tickets. (Added by the TicketBatch amendment.)
fn tick_size(&self) -> Result<Option<u8>>
fn tick_size(&self) -> Result<Option<u8>>
How many significant digits to use for exchange rates of Offers involving currencies issued by this address. Valid values are 3 to 15, inclusive. (Added by the TickSize amendment.)
fn transfer_rate(&self) -> Result<Option<u32>>
fn transfer_rate(&self) -> Result<Option<u32>>
A transfer fee to charge other users for sending currency issued by this account to each other.
fn wallet_locator(
&self,
) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>>
fn wallet_locator( &self, ) -> Result<Option<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>>
An arbitrary 256-bit value that users can set.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".