Trait EscrowFields
pub trait EscrowFields: LedgerObjectCommonFields {
Show 14 methods
// Provided methods
fn get_account(&self) -> Result<AccountID> { ... }
fn get_amount(&self) -> Result<Amount> { ... }
fn get_cancel_after(&self) -> Result<Option<u32>> { ... }
fn get_condition(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::ConditionBlob::{constant#0}>>> { ... }
fn get_destination(&self) -> Result<AccountID> { ... }
fn get_destination_node(&self) -> Result<Option<u64>> { ... }
fn get_destination_tag(&self) -> Result<Option<u32>> { ... }
fn get_finish_after(&self) -> Result<Option<u32>> { ... }
fn get_owner_node(&self) -> Result<u64> { ... }
fn get_previous_txn_id(
&self,
) -> Result<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>> { ... }
fn get_previous_txn_lgr_seq(&self) -> Result<u32> { ... }
fn get_source_tag(&self) -> Result<Option<u32>> { ... }
fn get_finish_function(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::WasmBlob::{constant#0}>>> { ... }
fn get_data(&self) -> Result<ContractData> { ... }
}Expand description
Trait providing access to fields specific to Escrow objects in any ledger.
This trait extends LedgerObjectCommonFields and provides methods to access
fields that are specific to Escrow objects in any ledger, not just the current one.
Each method requires a register number to identify which ledger object to access.
Provided Methods
fn get_account(&self) -> Result<AccountID>
fn get_account(&self) -> Result<AccountID>
The address of the owner (sender) of this escrow. This is the account that provided the XRP and gets it back if the escrow is canceled.
fn get_amount(&self) -> Result<Amount>
fn get_amount(&self) -> Result<Amount>
The amount of XRP, in drops, currently held in the escrow.
fn get_cancel_after(&self) -> Result<Option<u32>>
fn get_cancel_after(&self) -> Result<Option<u32>>
The escrow can be canceled if and only if this field is present and the time it specifies has passed. Specifically, this is specified as seconds since the Ripple Epoch and it “has passed” if it’s earlier than the close time of the previous validated ledger.
fn get_condition(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::ConditionBlob::{constant#0}>>>
fn get_condition( &self, ) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::ConditionBlob::{constant#0}>>>
A PREIMAGE-SHA-256 crypto-condition in full crypto-condition format. If present, the EscrowFinish transaction must contain a fulfillment that satisfies this condition.
fn get_destination(&self) -> Result<AccountID>
fn get_destination(&self) -> Result<AccountID>
The destination address where the XRP is paid if the escrow is successful.
fn get_destination_node(&self) -> Result<Option<u64>>
fn get_destination_node(&self) -> Result<Option<u64>>
A hint indicating which page of the destination’s owner directory links to this object, in case the directory consists of multiple pages. Omitted on escrows created before enabling the fix1523 amendment.
fn get_destination_tag(&self) -> Result<Option<u32>>
fn get_destination_tag(&self) -> Result<Option<u32>>
An arbitrary tag to further specify the destination for this escrow, such as a hosted recipient at the destination address.
fn get_finish_after(&self) -> Result<Option<u32>>
fn get_finish_after(&self) -> Result<Option<u32>>
The time, in seconds since the Ripple Epoch, after which this escrow can be finished. Any EscrowFinish transaction before this time fails. (Specifically, this is compared with the close time of the previous validated ledger.)
fn get_owner_node(&self) -> Result<u64>
fn get_owner_node(&self) -> Result<u64>
A hint indicating which page of the sender’s owner directory links to this entry, in case the directory consists of multiple pages.
fn get_previous_txn_id(
&self,
) -> Result<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>
fn get_previous_txn_id( &self, ) -> Result<UInt<xrpl_wasm_stdlib::::core::types::uint::UInt256::{constant#0}>>
The identifying hash of the transaction that most recently modified this entry.
fn get_previous_txn_lgr_seq(&self) -> Result<u32>
fn get_previous_txn_lgr_seq(&self) -> Result<u32>
The index of the ledger that contains the transaction that most recently modified this entry.
fn get_source_tag(&self) -> Result<Option<u32>>
fn get_source_tag(&self) -> Result<Option<u32>>
An arbitrary tag to further specify the source for this escrow, such as a hosted recipient at the owner’s address.
fn get_finish_function(
&self,
) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::WasmBlob::{constant#0}>>>
fn get_finish_function( &self, ) -> Result<Option<Blob<xrpl_wasm_stdlib::::core::types::blob::WasmBlob::{constant#0}>>>
The WASM code that is executing.
fn get_data(&self) -> Result<ContractData>
fn get_data(&self) -> Result<ContractData>
Retrieves the contract data from the specified ledger object.
This function fetches the data field from the ledger object at the specified register
and returns it as a ContractData structure. The data is read into a fixed-size buffer
of XRPL_CONTRACT_DATA_SIZE.
Arguments
register_num- The register number where the ledger object is stored
Returns
Returns a Result<ContractData> where:
Ok(ContractData)- Contains the retrieved data and its actual lengthErr(Error)- If the retrieval operation failed
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".